# t8s

[![PyPI - Version](https://img.shields.io/pypi/v/t8s.svg)](https://pypi.org/project/t8s)
[![PyPI - Python Version](https://img.shields.io/pypi/pyversions/t8s.svg)](https://pypi.org/project/t8s)

-----

**Table of Contents**

- [Installation](#installation)
- [License](#license)

## Installation

```console
pip install t8s
```

## Testing

```console
# Para inspecionar a configuração do ambiente de testes:
hatch config show
hatch clean
hatch build
hatch run python3 main.py
./test-all.sh
```

## License

`t8s` is distributed under the terms of the [MIT](https://spdx.org/licenses/MIT.html) license.
